from __future__ import annotations
from typing import Any, List, Optional, Protocol

class ChatPromptTemplate:
    @classmethod
    def from_messages(cls, messages: List[Any]) -> ChatPromptTemplate: ...
    def format_messages(self, **kwargs: Any) -> List[Any]: ...

class PromptTemplate:
    def __init__(self, template: str = ..., **kwargs: Any) -> None: ...
    def format(self, **kwargs: Any) -> str: ...

class RunnableConfig:
    def __init__(self, **kwargs: Any) -> None: ...

class Runnable(Protocol):
    def invoke(self, input: Any, config: Optional[RunnableConfig] = ...) -> Any: ...
